

.. _sphx_glr_content_user_guide_auto_examples_4validation:

4 | Validation
===============


.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Test the significance of individual modes and obtain confidence intervals for both EOFs and PCs...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/4validation/images/thumb/sphx_glr_plot_bootstrap_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_4validation_plot_bootstrap.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Significance testing of EOF analysis via bootstrap</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /content/user_guide/auto_examples/4validation/plot_bootstrap

